SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

CREATE SCHEMA IF NOT EXISTS `pristup` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci ;
USE `pristup` ;

-- -----------------------------------------------------
-- Table `pristup`.`radnik`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `pristup`.`radnik` (
  `radnik_id` INT NOT NULL AUTO_INCREMENT ,
  `korisnicko_ime` VARCHAR(20) NOT NULL ,
  `lozinka` VARCHAR(40) NOT NULL ,
  `email` VARCHAR(100) NOT NULL ,
  `ime_prezime` VARCHAR(100) NOT NULL ,
  `telefon` VARCHAR(45) NOT NULL ,
  PRIMARY KEY (`radnik_id`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `pristup`.`razlog`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `pristup`.`razlog` (
  `razlog_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `naziv` VARCHAR(45) NOT NULL ,
  PRIMARY KEY (`razlog_id`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `pristup`.`dnevnik`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `pristup`.`dnevnik` (
  `dnevnik_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `radnik_id` INT(11) NOT NULL ,
  `razlog_id` INT(11) NOT NULL ,
  `smijer` ENUM('ulaz','izlaz') NOT NULL DEFAULT "ulaz" ,
  `otkucano` INT(11) NOT NULL DEFAULT "0" COMMENT 'Koristimo Unix timestamp' ,
  `upisano` INT(11) NOT NULL DEFAULT "0" COMMENT 'Koristimo Unix timestamp' ,
  `izmijenjeno` INT(11) NOT NULL DEFAULT "0" COMMENT 'Koristimo Unix timestamp' ,
  PRIMARY KEY (`dnevnik_id`) ,
  INDEX `fk_dnevnik_razlog1_idx` (`razlog_id` ASC) ,
  INDEX `fk_dnevnik_radnik1_idx` (`radnik_id` ASC) ,
  CONSTRAINT `fk_dnevnik_razlog1`
    FOREIGN KEY (`razlog_id` )
    REFERENCES `pristup`.`razlog` (`razlog_id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_dnevnik_radnik1`
    FOREIGN KEY (`radnik_id` )
    REFERENCES `pristup`.`radnik` (`radnik_id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `pristup`.`sihtarica`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `pristup`.`sihtarica` (
  `sihtarica_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `radnik_id` INT(11) NOT NULL ,
  PRIMARY KEY (`sihtarica_id`) ,
  INDEX `fk_sihtarica_radnik_idx` (`radnik_id` ASC) ,
  CONSTRAINT `fk_sihtarica_radnik`
    FOREIGN KEY (`radnik_id` )
    REFERENCES `pristup`.`radnik` (`radnik_id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `pristup`.`sihtrarica_napomena`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `pristup`.`sihtrarica_napomena` (
  `napomena_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `sihtarica_id` INT(11) NOT NULL ,
  `napomena` TEXT NOT NULL ,
  PRIMARY KEY (`napomena_id`) ,
  INDEX `fk_sihtrarica_napomena_sihtarica1_idx` (`sihtarica_id` ASC) ,
  CONSTRAINT `fk_sihtrarica_napomena_sihtarica1`
    FOREIGN KEY (`sihtarica_id` )
    REFERENCES `pristup`.`sihtarica` (`sihtarica_id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `pristup`.`sihtarica_detalji`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `pristup`.`sihtarica_detalji` (
  `sihtarica_id` INT(11) NOT NULL ,
  `od` INT(11) NOT NULL ,
  `do` INT(11) NOT NULL DEFAULT "0" ,
  `iznos` DECIMAL NOT NULL DEFAULT "0" ,
  PRIMARY KEY (`sihtarica_id`, `od`) ,
  INDEX `fk_sihtarica_detalji_sihtarica1_idx` (`sihtarica_id` ASC) ,
  CONSTRAINT `fk_sihtarica_detalji_sihtarica1`
    FOREIGN KEY (`sihtarica_id` )
    REFERENCES `pristup`.`sihtarica` (`sihtarica_id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `pristup`.`tip_sata`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `pristup`.`tip_sata` (
  `tip_sata_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `vazi` ENUM('da','ne') NOT NULL DEFAULT "ne" COMMENT '	' ,
  `naziv` VARCHAR(45) NOT NULL ,
  `pocinje` TIME NOT NULL ,
  `zavrsava` TIME NOT NULL ,
  `datum_aktivacije` DATETIME NOT NULL ,
  `dan_u_sedmici` TINYINT(1) NULL ,
  PRIMARY KEY (`tip_sata_id`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `pristup`.`radnik_tip_sata`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `pristup`.`radnik_tip_sata` (
  `radnik_id` INT(11) NOT NULL ,
  `tip_sata_id` INT(11) NOT NULL ,
  `cijena` DECIMAL NOT NULL DEFAULT "0" ,
  `vazi_od` DATE NULL ,
  `vazi_do` DATE NULL ,
  INDEX `fk_radnik_tip_sata_tip_sata1_idx` (`tip_sata_id` ASC) ,
  INDEX `fk_radnik_tip_sata_radnik1_idx` (`radnik_id` ASC) ,
  CONSTRAINT `fk_radnik_tip_sata_tip_sata1`
    FOREIGN KEY (`tip_sata_id` )
    REFERENCES `pristup`.`tip_sata` (`tip_sata_id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_radnik_tip_sata_radnik1`
    FOREIGN KEY (`radnik_id` )
    REFERENCES `pristup`.`radnik` (`radnik_id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;



SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
